'use strict';

var _ = require('lodash');
var chalk = require('chalk');

var _require = require('lines-and-columns'),
    LinesAndColumns = _require.default;

module.exports = function (code, pos, options) {
  var linesCount = _.get(options, 'neighborLinesCount', 2);
  var colors = !!_.get(options, 'colors', true);
  var leftBrace = colors ? chalk.red('>') : '>';
  var bottomBrace = colors ? chalk.red('^') : '^';

  if (typeof pos === 'number') {
    var _lines = new LinesAndColumns(code);

    pos = _lines.locationForIndex(pos);
  } else {
    pos.line--;
  }

  var _pos = pos,
      line = _pos.line,
      column = _pos.column;

  var lines = code.split(/\r\n|\r|\n/);
  var lineNumberWidth = lines.length.toString().length;
  var startLine = Math.max(0, pos.line - linesCount);
  var beforeLines = lines.slice(startLine, pos.line);
  var afterLines = lines.slice(pos.line + 1, pos.line + linesCount + 1);

  return addLineNumbers(beforeLines, startLine + 1, ' ').concat(addLineNumbers([lines[line]], pos.line + 1, leftBrace)).concat(' '.repeat(lineNumberWidth + 5 + column) + bottomBrace).concat(addLineNumbers(afterLines, pos.line + 2, ' ')).join('\n');

  function addLineNumbers(lines, startLine, startCharacter) {
    return lines.map(function (line, index) {
      var lineNumber = _.padStart(startLine + index, lineNumberWidth);

      return startCharacter + ' ' + (colors ? chalk.blue(lineNumber) : lineNumber) + ' | ' + line;
    });
  }
};